@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
 
 extends 'W3C::SOAP::Parser';
 
-our $VERSION     = version->new('0.04');
+our $VERSION     = version->new('0.05');
 
 has '+document' => (
     isa      => 'W3C::SOAP::WSDL::Document',
@@ -70,11 +70,12 @@ sub write_modules {
     confess "No XSD modules found!\n" unless @modules;
 
     my $data = {
-        wsdl     => $wsdl,
-        module   => $self->module,
-        xsd      => shift @modules,
-        modules  => \@modules,
-        location => $self->location,
+        wsdl        => $wsdl,
+        module      => $self->module,
+        xsd         => shift @modules,
+        modules     => \@modules,
+        location    => $self->location,
+        w3c_version => $VERSION,
     };
     $template->process('wsdl/pm.tt', $data, "$file");
     confess "Error in creating $file (xsd.pm): ". $template->error."\n"
@@ -204,11 +205,11 @@ libraries to access the Web Service defined.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Parser version 0.04.
+This documentation refers to W3C::SOAP::WSDL::Parser version 0.05.
 
 =head1 SYNOPSIS
 
-   use W3C::SOAP::WSDL::Parser qw/load_wsdl?;
+   use W3C::SOAP::WSDL::Parser qw/load_wsdl/;
 
    # quick/simple usage
    # create a SOAP client
@@ -230,7 +231,7 @@ This documentation refers to W3C::SOAP::WSDL::Parser version 0.04.
 
    # Write the generated WSDL module to disk
    $wsdl->write_modules();
-   # would generate files
+   # may generate the files
    #   lib/MyApp/WSDL.pm
    #   lib/MyApp/XSD/Example.pm
    #   lib/MyApp/XSD/SomeOther.pm
@@ -246,7 +247,7 @@ There are two ways of using this file:
 
 =item 1
 
-Dynamic : C<<load_wsdl(...)> or C<W3C::SOAP::WSDL->new()->dynamic_classes>>
+Dynamic : C<load_wsdl(...)> or C<<W3C::SOAP::WSDL->new()->dynamic_classes>>
 
 These return an in memory generated WSDL client which you can use to talk
 to the specified web service.
@@ -292,7 +293,12 @@ Create the new object C<new> accepts the following arguments:
 
 =item location
 
-This is the location of the WSDL file, it may be a local file or a URL
+This is the location of the WSDL file, it may be a local file or a URL, it
+is used to create the C<document> attribute if not supplied.
+
+=item document
+
+A L<W3C::SOAP::Document> object representing the WSDL file.
 
 =item module
 
@@ -307,7 +313,8 @@ calling C<write_modules>
 
 =item template
 
-The Template Toolkit object used for the generation of on disk modules
+The Template Toolkit object used for the generation of on static modules
+when using the L</write_modules> method.
 
 =item ns_module_map
 
@@ -321,17 +328,17 @@ The mapping of XSD namespaces to perl Modules.
 
 =over 4
 
-=item C<$wsdl->write_modules ()>
+=item C<<$wsdl->write_modules ()>>
 
 Writes out a module that is a SOAP Client to interface with the contained
 WSDL document, also writes any referenced XSDs.
 
-=item C<$wsdl->dynamic_classes ()>
+=item C<<$wsdl->dynamic_classes ()>>
 
 Creates a dynamic SOAP client object to talk to the WSDL this object was
 created for
 
-=item C<$wsdl->get_xsd ()>
+=item C<<$wsdl->get_xsd ()>>
 
 Creates the L<W3C::SOAP::XSD::Parser> object that represents the XSDs that
 are used by the specified WSDL file.
