@@ -23,7 +23,9 @@ use W3C::SOAP::Utils qw/split_ns/;
 use TryCatch;
 use DateTime::Format::Strptime qw/strptime/;
 
-our $VERSION     = version->new('0.04');
+extends 'W3C::SOAP::Base';
+
+our $VERSION     = version->new('0.05');
 
 has xsd_ns => (
     is  => 'rw',
@@ -304,7 +306,7 @@ sub xsd_subtype {
 
     my $parent_type_name = $args{list} ? "ArrayRef[$parent_type]" : $parent_type;
     my $subtype = $parent_type =~ /^xsd:\w/xms && Moose::Util::TypeConstraints::find_type_constraint($parent_type_name);
-    return $subtype if $subtype;
+    return $subtype if $subtype && !$args{list};
 
     $subtype = subtype
         as $parent_type_name,
@@ -369,7 +371,7 @@ W3C::SOAP::XSD - The parent module for generated XSD modules.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD version 0.04.
+This documentation refers to W3C::SOAP::XSD version 0.05.
 
 =head1 SYNOPSIS
 
